---
name: Feature request
about: Suggest an improvement
title: "<Enter short description of desired feature>"
labels: enhancement
assignees: ''

---

**Short description of the feature**
Briefly describe the feature and its benefits. Let us know whether it is a new feature, or improves an existing feature. A few sentences are enough.

**Describe the solution you'd like**
A clear and concise description of what you want to happen. If possible, provide a code example of how this feature would be used.

**Describe alternatives and the context you have considered**
A clear and concise description of any alternative solutions or features you've considered. Describe shortly how you think your suggestion improves the project.
